#define QT_FEATURE_xcb 1
#define QT_FEATURE_accessibility_atspi_bridge 1
#define QT_FEATURE_angle_d3d11_qdtd -1
#define QT_FEATURE_direct2d -1
#define QT_FEATURE_directfb -1
#define QT_FEATURE_egl -1
#define QT_FEATURE_egl_x11 -1
#define QT_FEATURE_eglfs -1
#define QT_FEATURE_eglfs_brcm -1
#define QT_FEATURE_eglfs_egldevice -1
#define QT_FEATURE_eglfs_gbm -1
#define QT_FEATURE_eglfs_mali -1
#define QT_FEATURE_eglfs_openwfd -1
#define QT_FEATURE_eglfs_rcar -1
#define QT_FEATURE_eglfs_viv -1
#define QT_FEATURE_eglfs_viv_wl -1
#define QT_FEATURE_evdev -1
#define QT_FEATURE_freetype 1
#define QT_FEATURE_system_freetype 1
#define QT_FEATURE_fontconfig 1
#define QT_FEATURE_gif 1
#define QT_FEATURE_harfbuzz 1
#define QT_FEATURE_ico 1
#define QT_FEATURE_integrityfb -1
#define QT_FEATURE_integrityhid -1
#define QT_FEATURE_jpeg 1
#define QT_FEATURE_kms -1
#define QT_FEATURE_libinput -1
#define QT_FEATURE_libinput_axis_api -1
#define QT_FEATURE_linuxfb -1
#define QT_FEATURE_mirclient -1
#define QT_FEATURE_mtdev -1
#define QT_FEATURE_multiprocess 1
#define QT_FEATURE_png 1
#define QT_FEATURE_system_harfbuzz 1
#define QT_FEATURE_system_jpeg 1
#define QT_FEATURE_system_png 1
#define QT_FEATURE_system_xcb 1
#define QT_FEATURE_tslib -1
#define QT_FEATURE_vnc 1
#define QT_FEATURE_xcb_glx 1
#define QT_FEATURE_xcb_render 1
#define QT_FEATURE_xcb_sm 1
#define QT_FEATURE_xlib 1
#define QT_FEATURE_xcb_xlib 1
#define QT_FEATURE_xinput2 1
#define QT_FEATURE_xkb 1
#define QT_FEATURE_xkbcommon_system 1
#define QT_FEATURE_xkbcommon_evdev 1
